@@ -54,7 +54,7 @@ def get_thread_image(palette_name):
 
 def get_palette(palette_name):
     if palette_name in PALETTE_OVERRIDE.keys():
-        palette = PALETTE_OVERRIDE[palette_name]
+        palette_name = PALETTE_OVERRIDE[palette_name]
 
     if palette_name not in PALETTES:
         raise ValueError(
@@ -71,6 +71,7 @@ def get_palette(palette_name):
 
     return palette
 
+
 # This is a fun hack.
 #
 # Since we are limited to a colour palette of 256, but we might have >256
@@ -90,7 +91,8 @@ def reduce_palette(palette, image):
     best_colours = set()
 
     # Get image palette in RGB triplets
-    image_palette = image.getpalette()
+    im = image.convert("P", palette=Image.ADAPTIVE, colors=256)
+    image_palette = im.getpalette()
     my_colours = []
     for i in range (0, len(image_palette), 3):
         my_colours.append(image_palette[i:i+3])
@@ -104,7 +106,7 @@ def reduce_palette(palette, image):
     # Stick best_colours at the front of our palette
     first_colours = []
     for item in palette:
-        if item['hex'] in best_colours:
+        if item["hex"] in best_colours:
             first_colours.append(item)
 
     first_colours += palette
@@ -127,7 +129,7 @@ def get_palette_image(palette):
         sum([x["rgb"] for x in palette], [])
         + (palette[-1]["rgb"] * (256 - len(palette)))
     )[: 256 * 3]
-    image = Image.new("P", (1,1))
+    image = Image.new("P", (1, 1))
     image.putpalette(data)
 
     return image
